/*
 * Copyright (c) 2008 Jiri Svoboda
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup iramfs
 * @brief	Loads inlined data onto tmpfs.
 * @{
 */ 
/**
 * @file
 */

#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <vfs/vfs.h>
#include <sys/types.h>
#include "data.h"

#define min(a,b) ((a)>(b) ? (b) : (a))

int write_file(const uint8_t *data, size_t length, const char *file_name)
{
	int nbytes;
	uint8_t *dp;
	int written;
	int fd;
	int cnt;

	printf("Create %s\n", file_name);

	fd = open(file_name, O_CREAT);
	if (fd < 0) { printf("open failed\n"); return -1; }

	printf("write %d bytes...\n", length);
	nbytes = length; dp = data; written = 0;
	while (nbytes > 0) {
		cnt = write(fd, dp, min(16384, nbytes));
		if (cnt < 0) { printf("write failed\n"); return -1; }
		dp += cnt;
		written += cnt;
		nbytes -= cnt;
		printf("written: %d, cnt: %d, left: %d\n", written, cnt, nbytes);
	}

	printf("\nwritten %d bytes\n", written);
	close(fd);

	return 0;
}

int main(int argc, char *argv[])
{
	int rc;

	printf("This is iramfs\n");
	do {
		rc = mount("tmpfs", "/", "nulldev0");
		printf("mount tmpfs on / -> %d\n", rc);
		if (rc == 0) break;

		usleep(1000 * 1000);
	} while (1);

//	if (write_file(rtld, rtld_size, rtld_filename) < 0) return 1;
//	if (write_file(dltest, dltest_size, dltest_filename) < 0) return 1;
//	if (write_file(libc, libc_size, libc_filename) < 0) return 1;
	if (write_file(tetris, tetris_size, tetris_filename) < 0) return 1;

	printf("done\n");
	getchar();
	return 0;
}

/** @}
 */
